@@ -1,4 +1,4 @@
-// $Id: Agent.h,v 1.20 1999/08/19 11:27:01 andreas Exp $
+// $Id$
 // Three-Channel Agent Interface 
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -95,15 +95,16 @@
 #include <signal.h>
 #include <sys/types.h>
 #include <unistd.h>
-#include <iostream.h>
-#include <strstream.h>
+#include <iostream>
+#include <sstream>
 #include <errno.h>
 #include <string.h>
 
 #if !HAVE_STRERROR_DECL
-extern "C" char *strerror(int errno);
+extern "C" char *strerror(int);
 #endif
 
+#include "casts.h"
 #include "strclass.h"
 #include "bool.h"
 #include "AgentM.h"
@@ -204,9 +205,9 @@ private:
     {
 	if (system_error)
 	    msg += string(": ") + strerror(errno);
-	char *s = msg;
+	const char *s = msg.chars();
 
-	callHandlers(handler, (void *)s);
+	callHandlers(handler, STATIC_CAST(void *,CONST_CAST(char*,s)));
 
 	if (check_if_running)
 	    (void)running();
@@ -414,7 +415,7 @@ public:
 
     string name() const
     {
-	ostrstream os;
+	std::ostringstream os;
 	os << path();
 	if (pid() > 0)
 	    os << " [" << pid() << "]";
