@@ -1,4 +1,4 @@
-// $Id: AppData.h,v 1.139 2001/01/17 13:44:56 zeller Exp $ -*- C++ -*-
+// $Id$ -*- C++ -*-
 // DDD application data
 
 // Copyright (C) 1996-1998 Technische Universitaet Braunschweig, Germany.
@@ -73,6 +73,8 @@
 #define XtNpydbSettings          "pydbSettings"
 #define XtNperlInitCommands      "perlInitCommands"
 #define XtNperlSettings          "perlSettings"
+#define XtNbashInitCommands      "bashInitCommands"
+#define XtNbashSettings          "bashSettings"
 #define XtNrestartCommands       "restartCommands"
 #define XtCInitCommands          "InitCommands"
 #define XtNsourceInitCommands    "sourceInitCommands"
@@ -125,6 +127,7 @@
 #define XtNjdbDisplayShortcuts   "jdbDisplayShortcuts"
 #define XtNpydbDisplayShortcuts  "pydbDisplayShortcuts"
 #define XtNperlDisplayShortcuts  "perlDisplayShortcuts"
+#define XtNbashDisplayShortcuts  "bashDisplayShortcuts"
 #define XtCDisplayShortcuts      "DisplayShortcuts"
 #define XtNconsoleButtons        "consoleButtons"
 #define XtNsourceButtons         "sourceButtons"
@@ -251,7 +254,8 @@
 #define XtNglobalTabCompletion   "globalTabCompletion"
 #define XtCGlobalTabCompletion   "GlobalTabCompletion"
 #define XtNsaveHistoryOnExit     "saveHistoryOnExit"
-#define XtCSaveHistoryOnExit     "SaveHistoryOnExit"
+#define XtNsaveOptionsOnExit     "saveOptionsOnExit"
+#define XtCSaveOnExit            "SaveOnExit"
 #define XtNcacheSourceFiles      "cacheSourceFiles"
 #define XtCCacheSourceFiles      "CacheSourceFiles"
 #define XtNcacheMachineCode      "cacheMachineCode"
@@ -417,42 +421,44 @@
 #define XtCVersion               "Version"
 
 struct AppData {
-    String    session;
-    String    initial_session;
+    const _XtString    session;
+    const _XtString    initial_session;
     const _XtString    debugger;
     const _XtString    debugger_command;
     Boolean   auto_debugger;
     Boolean   open_selection;
     Boolean   trace;
-    String    play_log;
-    String    gdb_init_commands;
-    String    gdb_settings;
-    String    dbx_init_commands;
-    String    dbx_settings;
-    String    xdb_init_commands;
-    String    xdb_settings;
-    String    jdb_init_commands;
-    String    jdb_settings;
-    String    pydb_init_commands;
-    String    pydb_settings;
-    String    perl_init_commands;
-    String    perl_settings;
-    String    restart_commands;
+    const _XtString    play_log;
+    const _XtString    gdb_init_commands;
+    const _XtString    gdb_settings;
+    const _XtString    dbx_init_commands;
+    const _XtString    dbx_settings;
+    const _XtString    xdb_init_commands;
+    const _XtString    xdb_settings;
+    const _XtString    jdb_init_commands;
+    const _XtString    jdb_settings;
+    const _XtString    pydb_init_commands;
+    const _XtString    pydb_settings;
+    const _XtString    perl_init_commands;
+    const _XtString    bash_init_commands;
+    const _XtString    bash_settings;
+    const _XtString    perl_settings;
+    const _XtString    restart_commands;
     Boolean   source_init_commands;
-    String    init_symbols;
-    String    vsl_path;
-    String    vsl_library;
-    String    vsl_defs;
-    String    vsl_base_defs;
-    String    default_font;
-    String    variable_width_font;
-    String    fixed_width_font;
-    String    data_font;
+    const _XtString    init_symbols;
+    const _XtString    vsl_path;
+    const _XtString    vsl_library;
+    const _XtString    vsl_defs;
+    const _XtString    vsl_base_defs;
+    const _XtString    default_font;
+    const _XtString    variable_width_font;
+    const _XtString    fixed_width_font;
+    const _XtString    data_font;
     Cardinal  default_font_size;
     Cardinal  variable_width_font_size;
     Cardinal  fixed_width_font_size;
     Cardinal  data_font_size;
-    String    font_select_command;
+    const _XtString    font_select_command;
     Cardinal  tab_width;
     Cardinal  lines_above_cursor;
     Cardinal  lines_below_cursor;
@@ -463,17 +469,18 @@ struct AppData {
     Boolean   source_editing;
     Boolean   line_buffered_console;
     OnOff     console_has_focus;
-    String    gdb_display_shortcuts;
-    String    dbx_display_shortcuts;
-    String    xdb_display_shortcuts;
-    String    jdb_display_shortcuts;
-    String    pydb_display_shortcuts;
-    String    perl_display_shortcuts;
-    String    console_buttons;
-    String    source_buttons;
-    String    data_buttons;
-    String    tool_buttons;
-    String    label_delimiter;
+    const _XtString    gdb_display_shortcuts;
+    const _XtString    dbx_display_shortcuts;
+    const _XtString    xdb_display_shortcuts;
+    const _XtString    jdb_display_shortcuts;
+    const _XtString    pydb_display_shortcuts;
+    const _XtString    perl_display_shortcuts;
+    const _XtString    bash_display_shortcuts;
+    const _XtString    console_buttons;
+    const _XtString    source_buttons;
+    const _XtString    data_buttons;
+    const _XtString    tool_buttons;
+    const _XtString    label_delimiter;
     Boolean   command_toolbar;
     Boolean   common_toolbar;
     Boolean   separate_data_window;
@@ -483,15 +490,15 @@ struct AppData {
     Boolean   source_window;
     Boolean   debugger_console;
     Boolean   auto_close_data_window;
-    String    plot_command;
+    const _XtString    plot_command;
     const _XtString    plot_term_type;
-    String    plot_window_class;
+    const _XtString    plot_window_class;
     Cardinal  plot_window_delay;
-    String    plot_init_commands;
-    String    plot_2d_settings;
-    String    plot_3d_settings;
-    String    term_command;
-    String    term_type;
+    const _XtString    plot_init_commands;
+    const _XtString    plot_2d_settings;
+    const _XtString    plot_3d_settings;
+    const _XtString    term_command;
+    const _XtString    term_type;
     Boolean   use_tty_command;
     int       question_timeout;
     int       position_timeout;
@@ -502,20 +509,20 @@ struct AppData {
     int       run_interrupt_delay;
     int       cont_interrupt_delay;
     Boolean   poll_child_status;
-    String    debugger_host;
-    String    debugger_rhost;
-    String    debugger_host_login;
-    String    rhost_init_commands;
-    String    rsh_command;
+    const _XtString    debugger_host;
+    const _XtString    debugger_rhost;
+    const _XtString    debugger_host_login;
+    const _XtString    rhost_init_commands;
+    const _XtString    rsh_command;
     Boolean   filter_files;
-    String    list_exec_command;
-    String    list_source_command;
-    String    list_core_command;
-    String    list_dir_command;
-    String    uncompress_command;
-    String    ps_command;
-    String    www_page;
-    String    www_command;
+    const _XtString    list_exec_command;
+    const _XtString    list_source_command;
+    const _XtString    list_core_command;
+    const _XtString    list_dir_command;
+    const _XtString    uncompress_command;
+    const _XtString    ps_command;
+    const _XtString    www_page;
+    const _XtString    www_command;
     Boolean   show_invocation;
     Boolean   show_version;
     Boolean   show_configuration;
@@ -524,10 +531,10 @@ struct AppData {
     Boolean   show_news;
     Boolean   show_fonts;
     Boolean   check_configuration;
-    String    print_command;
-    String    paper_size;
-    String    edit_command;
-    String    get_core_command;
+    const _XtString    print_command;
+    const _XtString    paper_size;
+    const _XtString    edit_command;
+    const _XtString    get_core_command;
     Boolean   panned_graph_editor;
     Boolean   find_words_only;
     Boolean   find_case_sensitive;
@@ -536,6 +543,7 @@ struct AppData {
     Boolean   transient_dialogs;
     Boolean   global_tab_completion;
     Boolean   save_history_on_exit;
+    Boolean   save_options_on_exit;
     Boolean   cache_source_files;
     Boolean   cache_machine_code;
     Boolean   suppress_warnings;
@@ -577,7 +585,7 @@ struct AppData {
     Boolean   check_grabs;
     Cardinal  check_grab_delay;
     Cardinal  grab_action_delay;
-    String    grab_action;
+    const _XtString    grab_action;
     Boolean   detect_aliases;
     Boolean   typed_aliases;
     Boolean   delete_alias_displays;
@@ -603,13 +611,13 @@ struct AppData {
     Position  tool_top_offset;
     Boolean   button_captions;
     Boolean   button_images;
-    String    button_caption_geometry;
-    String    button_image_geometry;
+    const _XtString    button_caption_geometry;
+    const _XtString    button_image_geometry;
     Boolean   flat_toolbar_buttons;
     Boolean   flat_dialog_buttons;
     const _XtString    button_color_key;
     const _XtString    active_button_color_key;
-    String    splash_screen_color_key;
+    const _XtString    splash_screen_color_key;
     Boolean   auto_commands;
     const _XtString    auto_command_prefix;
     int       max_breakpoint_number;
@@ -620,14 +628,14 @@ struct AppData {
     BindingStyle select_all_bindings;
     int       max_undo_depth;
     int       max_undo_size;
-    String    themes;
-    String    suppress_theme;
+    const _XtString    themes;
+    const _XtString    suppress_theme;
     Boolean   maintenance;
     Boolean   dump_core;
     Boolean   debug_core_dumps;
     int       lesstif_version;
     const _XtString    dddinit_version;
-    String    app_defaults_version;
+    const _XtString    app_defaults_version;
 };
 
 extern AppData app_data;
