@@ -1,4 +1,4 @@
-// $Id: BoxExtend.h,v 1.11 1999/08/19 11:27:07 andreas Exp $  -*- C++ -*-
+// $Id$  -*- C++ -*-
 // BoxExtend class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -126,7 +126,7 @@ public:
 };
 
 // I/O
-inline ostream& operator << (ostream& stream, const BoxExtend& extend)
+inline std::ostream& operator << (std::ostream& stream, const BoxExtend& extend)
 {
     const BoxPoint& p = extend;
     return operator << (stream, p);
