@@ -1,4 +1,4 @@
-// $Id: BoxGraphN.h,v 1.15 1999/08/19 11:27:07 andreas Exp $
+// $Id$
 // BoxGraphNode class: RegionGraphNode with box
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -115,7 +115,7 @@ public:
     void setBox(Box *b);
 
     // Print
-    virtual void _print(ostream& os, const GraphGC& gc) const;
+    virtual void _print(std::ostream& os, const GraphGC& gc) const;
 };
 
 #endif // _DDD_BoxGraphNode_h
