@@ -1,4 +1,4 @@
-// $Id: BuiltinCN.h,v 1.11 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // Calling built-in VSL functions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -38,7 +38,7 @@
 
 
 #include "assert.h"
-#include <iostream.h>
+#include <iostream>
 
 #include "VSLBuiltin.h"
 
