@@ -1,4 +1,4 @@
-// $Id: ChunkQueue.h,v 1.15 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // Chunk buffer
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -123,8 +123,7 @@ public:
     }
 
     // Resources
-    // TODO should return a const char*
-    char *data() { return _data; }
+    const char *data() { return _data; }
     int length() { return _length; }
 };
 
