@@ -1,4 +1,4 @@
-// $Id: CompositeB.h,v 1.16 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // Composite boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -91,7 +91,7 @@ protected:
     }
 
     // Dump
-    void dumpComposite(ostream& s, 
+    void dumpComposite(std::ostream& s, 
 	const char *sep = ", ", const char *head = "(", const char *tail = ") ") const;
 
     bool matches (const Box &, const Box * = 0) const;
