@@ -1,4 +1,4 @@
-// $Id: DefCallN.h,v 1.14 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // Calling user-defined VSL functions
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -38,7 +38,7 @@
 
 
 #include "assert.h"
-#include <iostream.h>
+#include <iostream>
 
 #include "VSLNode.h"
 #include "CallNode.h"
