@@ -1,4 +1,4 @@
-// $Id: DummyBox.h,v 1.11 2000/12/11 12:21:47 zeller Exp $ 
+// $Id$ 
 // `Dummy' boxes (for pattern matching)
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -61,7 +61,7 @@ protected:
 	ListBox(box)
     {}
 
-    void dump(ostream& s) const;
+    void dump(std::ostream& s) const;
 
     bool matches (const Box &b, const Box *callbackArg = 0) const;
 
