@@ -1,4 +1,4 @@
-// $Id: ListNode.h,v 1.17 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // ListNode class
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -39,7 +39,7 @@
 
 
 #include "assert.h"
-#include <iostream.h>
+#include <iostream>
 #include "misc.h"       // max()
 
 #include "VSLNode.h"
@@ -114,8 +114,8 @@ public:
     int append(VSLNode *node);
 
     // Dump
-    void dump(ostream& s) const;
-    void _dumpTree(ostream& s) const;
+    void dump(std::ostream& s) const;
+    void _dumpTree(std::ostream& s) const;
 
     // Properties
     bool isConst() const;
