@@ -1,4 +1,4 @@
-// $Id: NameNode.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // VSL Variable names
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -38,7 +38,7 @@
 
 
 #include "assert.h"
-#include <iostream.h>
+#include <iostream>
 #include "strclass.h"
 
 #include "VSLNode.h"
@@ -59,8 +59,8 @@ protected:
 	_name(node._name)
     {}
 
-    void dump(ostream& s) const;
-    void _dumpTree(ostream& s) const;
+    void dump(std::ostream& s) const;
+    void _dumpTree(std::ostream& s) const;
 
 public:
     // Constructor
