@@ -1,4 +1,4 @@
-// $Id: RegionGN.h,v 1.16 1999/08/19 11:27:49 andreas Exp $
+// $Id$
 // RegionGraphNode class: PosGraphNode with rectangular region
 // centered around position
 
@@ -103,7 +103,7 @@ public:
 		      const GraphGC& gc) const;
 
     // Print
-    virtual void _print(ostream& os, const GraphGC& gc) const;
+    virtual void _print(std::ostream& os, const GraphGC& gc) const;
 
     // Attributes
     // Region occupied by this node
