@@ -1,4 +1,4 @@
-// $Id: StringBox.h,v 1.14 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // A String Box contains a string
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -66,7 +66,7 @@ protected:
 	_font(box._font), _ascent(box._ascent)
     {}
 
-    void dump(ostream& s) const;
+    void dump(std::ostream& s) const;
 
     bool matches (const Box &b, const Box * = 0) const
     {
@@ -110,13 +110,14 @@ public:
     // Assign a new font
     void newFont(const string& fontname);
 
-    void _print(ostream& os, 
+    void _print(std::ostream& os, 
 		const BoxRegion& region, 
 		const PrintGC& gc) const;
 
     // Resources
     const XFontStruct *font() const { return _font; }
     const string& fontName() const  { return _fontname; }
+    const char *fontName_c() const { return _fontname.chars(); }
     virtual string str() const { return _string; }
 
     Box *resize();
