@@ -1,4 +1,4 @@
-// $Id: TagBox.h,v 1.13 1999/08/19 11:27:59 andreas Exp $
+// $Id$
 // Tagged boxes
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -70,7 +70,7 @@ protected:
 	_data((*(tagbox.datalink->link))(tagbox._data))
     {}
 
-    void dump(ostream& s) const;
+    void dump(std::ostream& s) const;
 
     // Find TagBox within P
     const TagBox *findTag(const BoxPoint&) const;
