@@ -1,4 +1,4 @@
-// $Id: TestNode.h,v 1.12 2000/12/11 12:21:47 zeller Exp $
+// $Id$
 // VSL if..then..else..fi construct
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -42,7 +42,7 @@
 
 
 #include "assert.h"
-#include <iostream.h>
+#include <iostream>
 
 #include "VSLNode.h"
 #include "ListNode.h"
@@ -63,8 +63,8 @@ private:
     ListNode *_false() const { return (ListNode *)(_true()->tail()); }
 
 protected:
-    void dump(ostream& s) const;
-    void _dumpTree(ostream& s) const;
+    void dump(std::ostream& s) const;
+    void _dumpTree(std::ostream& s) const;
 
     TestNode(const TestNode& node):
 	CallNode(node)
