@@ -1,4 +1,4 @@
-// $Id: VSLDef.h,v 1.16 2000/05/30 19:16:30 andreas Exp $
+// $Id$
 // VSL definition
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -36,7 +36,7 @@
 
 
 #include <limits.h>
-#include <iostream.h>
+#include <iostream>
 #include "strclass.h"
 #include "bool.h"
 #include "VSLNode.h"
