@@ -1,4 +1,4 @@
-// $Id: annotation.h,v 1.3 1999/08/19 11:28:09 andreas Exp $ -*- C++ -*-
+// $Id$ -*- C++ -*-
 // Create an edge annotation
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -37,7 +37,7 @@
 #include "GDBAgent.h"
 
 // Return an annotation for an edge from FROM to TO
-extern string annotation(string from, string to);
+extern string annotation(const string& from, const string& to);
 
 #endif // _DDD_annotation_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
