@@ -1,4 +1,4 @@
-// $Id: plotter.h,v 1.4 1999/08/19 11:28:47 andreas Exp $ -*- C++ -*-
+// $Id$ -*- C++ -*-
 // Create a plotter interface
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -39,7 +39,7 @@
 class DispValue;
 
 // Create a new plot window
-PlotAgent *new_plotter(string name, DispValue *src);
+PlotAgent *new_plotter(const string& name, DispValue *src);
 
 // Clear cached plot decorations
 void clear_plot_window_cache();
