@@ -1,4 +1,4 @@
-// $Id: session.h,v 1.22 2000/06/16 08:50:33 andreas Exp $ -*- C++ -*-
+// $Id$ -*- C++ -*-
 // DDD session management
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
@@ -90,7 +90,7 @@ inline string session_tmp_flag(const string& session)
 }
 
 // Create session directory for SESSION; leave messages in MSG
-void create_session_dir(const string& session, ostream& msg);
+void create_session_dir(const string& session, std::ostream& msg);
 
 // Same, but leave messages in status line
 void create_session_dir(const string& session);
@@ -134,7 +134,7 @@ bool is_saved_session(const string& session);
 bool is_temporary_session(const string& session);
 
 // Set temporary flag of SESSION
-void set_tmeporary_session(const string& session, bool temporary);
+void set_temporary_session(const string& session, bool temporary);
 
 // Set name of session to be restarted with
 void set_restart_session(const string& session = "");
