@@ -1,4 +1,4 @@
-// $Id: value-read.h,v 1.25 2000/02/11 20:41:10 andreas Exp $
+// $Id$
 // Read variable values in string representation
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -41,10 +41,10 @@
 #include "bool.h"
 #include "DispValueT.h"
 
-#include <iostream.h>
+#include <iostream>
 
 // Determine type of next element in VALUE
-DispValueType determine_type (const string& value);
+DispValueType determine_type (string& value);
 
 // Read single token from VALUE
 string read_token (string& value);
